|
Pre-allocate for findall
|
|
16
|
749
|
September 19, 2022
|
|
Allocation during construction of compile-time sized structure
|
|
1
|
401
|
September 18, 2022
|
|
Nice work on Julia 1.8/1.8.1 on MacOS ARM
|
|
0
|
311
|
September 16, 2022
|
|
Shouldn't 1.8.0 be faster than Julia 1.7?
|
|
30
|
2980
|
September 16, 2022
|
|
Question on Julia Blog Post regarding Performance
|
|
1
|
414
|
September 16, 2022
|
|
Code in Threads.@threads takes longer than in single-threaded code
|
|
0
|
274
|
September 15, 2022
|
|
Threads.@threads ~44 times slower than single threaded code
|
|
8
|
812
|
September 14, 2022
|
|
Slow `reduce(vcat, itr)`
|
|
26
|
1830
|
September 13, 2022
|
|
FLoops for updating a vector by index
|
|
7
|
612
|
September 13, 2022
|
|
Constant propagation: Irrationals doing much better than Float64
|
|
15
|
725
|
September 13, 2022
|
|
Forcing data points containing one sinusoidal signal to be symetric around zero and multithreading
|
|
4
|
380
|
September 12, 2022
|
|
Outer-only constructors and concrete types
|
|
4
|
518
|
September 12, 2022
|
|
Copy the return value of a function to the clipboard
|
|
1
|
344
|
September 12, 2022
|
|
Julia in Colab suddenly does not work
|
|
0
|
326
|
September 12, 2022
|
|
Multithreading in many nested loops
|
|
1
|
667
|
September 9, 2022
|
|
Why more BLAS threads take more time
|
|
2
|
596
|
September 9, 2022
|
|
Fast small integer matrix multiplication
|
|
11
|
731
|
September 9, 2022
|
|
~7x compliation time regression in the following data reading code
|
|
6
|
543
|
September 9, 2022
|
|
Utilizing @turbo / @tturbo in Performance Critical Code
|
|
4
|
1009
|
September 8, 2022
|
|
How to passing vargs... to a function without allocation?
|
|
4
|
476
|
September 6, 2022
|
|
Advice on speeding up highly parallel and I/O intensive code
|
|
4
|
652
|
September 5, 2022
|
|
BenchmarkTools for benchmarking thread scalability of functions
|
|
6
|
1733
|
September 5, 2022
|
|
Zygote and StaticArrays
|
|
12
|
1458
|
September 5, 2022
|
|
Is @evalpoly needed anymore?
|
|
1
|
582
|
September 3, 2022
|
|
How to avoid allocations when reading arbitrary keys from a NamedTuple?
|
|
8
|
1232
|
September 2, 2022
|
|
Any small example of a queue like system, where a function is automatically executed when a new item pops in the queue?
|
|
12
|
1323
|
September 2, 2022
|
|
Priority queue choice
|
|
24
|
3687
|
September 1, 2022
|
|
Fast(er) priority queues?
|
|
20
|
2567
|
September 1, 2022
|
|
Container of mutable structs without 100x slowdown?
|
|
7
|
1399
|
September 1, 2022
|
|
Directly modify compiled method without recompilation
|
|
25
|
1511
|
August 31, 2022
|